@@ -76,9 +76,7 @@ class display_volume_detail(DetailView):
                         )
                         stat_type = client_stat_entry.type.name
                         stat_value = client_stat_entry.value
-                            client_data[stat_type] = (
-                                client_data.get(stat_type, 0) + stat_value
-                            )
+                            client_data[stat_type] = (client_data.get(stat_type, 0) + stat_value)
 
             all_clients_data.append(client_data)
 
